@@ -1,5 +1,7 @@
+from sqlalchemy.orm import defer
 from sqlalchemy.orm.mapper import Mapper
 from sqlalchemy.orm.query import _ColumnEntity
+from sqlalchemy.orm.properties import ColumnProperty
 from sqlalchemy.sql.expression import desc, asc
 
 
@@ -113,6 +115,30 @@ def sort_query(query, sort):
     return query
 
 
+def defer_except(query, columns):
+    """
+    Deferred loads all columns in given query, except the ones given.
+
+    This function is very useful when working with models with myriad of
+    columns and you want to deferred load many columns.
+
+        >>> from sqlalchemy_utils import defer_except
+        >>> query = session.query(Article)
+        >>> query = defer_except(Article, [Article.id, Article.name])
+
+    :param columns: columns not to deferred load
+    """
+    model = query._entities[0].entity_zero.class_
+    fields = set(model._sa_class_manager.values())
+    for field in fields:
+        property_ = field.property
+        if isinstance(property_, ColumnProperty):
+            column = property_.columns[0]
+            if column.name not in columns:
+                query = query.options(defer(property_.key))
+    return query
+
+
 def escape_like(string, escape_char='*'):
     """
     Escapes the string paremeter used in SQL LIKE expressions
